/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.util.jmx.api;

/**
 * Allow to register BaseModelMbeanExt with an id.<br>
 * Each attributes and operations are associate with a regexp used to register them on all matching BaseModelMbeanExt.
 * @author missonng
 */
public interface ICommonsModelerExtService {
    /**
     * Start the service.
     */
    void start();

    /**
     * Stop the service.
     */
    void stop();

    /**
     * Get the BaseModelMBeanExt with the given id.
     * @param id The id of the BaseModelMBeanExt to get.
     * @return The BaseModelMBeanExt with the given id.
     */
    IBaseModelMBeanExt getBaseModelMBeanExt(String id);

    /**
     * Register a new BaseModelMBeanExt.
     * @param id The id to register the BaseModelMBeanExt with.
     * @param mbean The BaseModelMBeanExt to register.
     */
    void registerBaseModelMBeanExt(String id, IBaseModelMBeanExt mbean);

    /**
     * Unregister a BaseModelMBeanExt.
     * @param id The id to unregister.
     */
    void unregisterBaseModelMBeanExt(String id);

    /**
     * Register a new attribute.<br>
     * The attribute will automatically be register with each registered BaseModelMBeanExt matching the given regexp.
     * @param attribute The attribute to register.
     * @param regexp The regexp to apply.
     */
    void registerAttribute(IMBeanAttribute attribute, String regexp);

    /**
     * Unregister an attribute.
     * @param attribute The attribute to unregister.
     */
    void unregisterAttribute(IMBeanAttribute attribute);

    /**
     * Register a new operation.<br>
     * The operation will automatically be register with each registered BaseModelMBeanExt matching the given regexp.
     * @param operation The operation to register.
     * @param regexp The regexp to apply.
     */
    void registerOperation(IMBeanOperation operation, String regexp);

    /**
     * Unregister an operation.
     * @param operation The operation to unregister.
     */
    void unregisterOperation(IMBeanOperation operation);
}
